@@ -16,10 +16,10 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
 test_that("crm_xml works with links input",{
   skip_on_cran()
 
-  vcr::use_cassette("crm_xml_links_in", {
-    links <- crm_links("10.3897/compcytogen.v10i4.9536", type = "all")
-    res <- suppressMessages(crm_xml(links))
-  }, preserve_exact_body_bytes = TRUE)
+  # vcr::use_cassette("crm_xml_links_in", {
+  links <- crm_links("10.3897/compcytogen.v10i4.9536", type = "all")
+  res <- suppressMessages(crm_xml(links))
+  # }, preserve_exact_body_bytes = TRUE)
   expect_is(res, "xml_document")
   expect_equal(xml2::xml_name(res), "article")
 })
@@ -27,9 +27,9 @@ test_that("crm_xml works with links input",{
 test_that("crm_xml works with character URL input", {
   skip_on_cran()
 
-  vcr::use_cassette("crm_xml_character_in", {
-    res <- suppressMessages(crm_xml(url1$xml))
-  })
+  # vcr::use_cassette("crm_xml_character_in", {
+  res <- suppressMessages(crm_xml(url1$xml))
+  # })
   expect_is(res, "xml_document")
   expect_equal(xml2::xml_name(res), "article")
 })
